#!/bin/bash
#
# rub single_node MPI test
# Author Simon Michnowicz
# 20 Aug 20
#
# usage:  run_single_node.sh <NameofNodeRebuilt> <ReservationName>

#check commadn line includes host

hostname=""
reservationName=""
partitionName=comp

################################################
function printUsage
{
    echo "$0 To test a new or updated node, it runs a simple MPI job on it "
    echo "Usage: run_single_node.sh --newnode=<node> --reservation=<res> [ --partition=<partition> ] "
    echo "e.g. run_single_node.sh --newnode=gf00 --reservation=monMaintenance" 
    echo "e.g. run_single_node.sh --newnode=gf00 --reservation=monMaintenance --partition=gpu " 
    echo "Where"
    echo "<node> is the name of the updated host we wish to test"
    echo "<res> is the name of the SLURM reservation"
    echo "<partition> is the name of the SLURM partition (defaults to comp)"
    echo ""
    #echo "We also support short options, i.e. -n -r -P "
    exit 0
}
################################################

function parseARG
{
OPTS="--long help:: --long newnode: --long reservation: --long partition:: -o nr:,hP::"

#echo "getopt  $OPTS -n $0  -- $@"
TEMP=`getopt  $OPTS -n $0  -- "$@"`
if [ $? != 0 ] ; then echo "Failed parsing options." >&2 ; exit 1 ; fi
eval set -- "$TEMP"
#echo "Output is $TEMP"
while true; do
    #echo "Parameter is $1"
    case "$1" in
     -n|--newnode) # Specify p value.
       newnode=$2 
       shift 2
       #echo "Newnode is $newnode"
      ;;
    -r|--reservation) # Specify strength, either 45 or 90.
      reservation=$2
      shift 2
      #echo "Reservation is $reservation"
      ;;
    -P|--partition) # Specify p value.
      partition=$2
      shift 2
      #echo "partition is ${partition}"
      ;;
    #
    # -- means the end of the arguments; drop this, and break out of the while loop
    #
    --) shift; break ;;
    h | *) # Display help.
      echo "In h option"
      printUsage
      exit 0
      ;;
  esac
done
}
################################################
#main
################################################

#force a timeout if srun hangs
TIMEOUT=2m
echo "PID is $$"
(sleep $TIMEOUT && kill $$ ) &

#parse arguments
parseARG $0 "$@"

echo "newnode=$newnode"
echo "reservation=$reservation"
echo "partition=$partition"

if [ -z $newnode ] 
then
    echo "You need to specify a nodename "
    printUsage
    exit 1
fi

if [ -z $reservation ] 
then
    echo "You need to specify a reservation "
    printUsage
    exit 1
fi


#######################
# compile and run mpi job
#######################
module load openmpi/1.10.7-mlx
mpic++ -o rotateMPI.exe rotate.cpp

if [ ! -e rotateMPI.exe ] 
then
    echo "Error trying to compile rotateMPI.exe"
    echo "Exiting"
    exit 1
fi

SLURM_PARAMETERS="--nodes=1 --tasks-per-node=2 --cpus-per-task=1 --partition=${partition}"
SLURM_PARAMETERS="${SLURM_PARAMETERS} --reservation=${reservation} --nodelist=${hostname}"
echo "srun ${SLURM_PARAMETERS} rotateMPI.exe"
srun ${SLURM_PARAMETERS} rotateMPI.exe
retValue=$?
echo "retValue is $retValue"
if [ $retValue -ne "0" ]
then
    echo "FAILURE TO RUN rotateMPI.exe as a slurm job"
    exit $retValue
fi
echo "##############################"
echo "srun test OK"
echo "##############################"
exit 0
